@@ -13,6 +13,19 @@
 class ContentItem;
 class ColumnView;
 
+class ScrollIntentionEvent : public QObject {
+    Q_OBJECT
+    Q_PROPERTY(QPointF delta MEMBER delta CONSTANT)
+    Q_PROPERTY(bool accepted MEMBER accepted)
+public:
+    ScrollIntentionEvent(){}
+    ~ScrollIntentionEvent(){}
+
+    QPointF delta;
+    bool accepted = false;
+};
+
+
 /**
  * This is an attached property to every item that is inserted in the ColumnView,
  * used to access the view and page information such as the position and informations for layouting, such as fillWidth
@@ -55,6 +68,12 @@ class ColumnViewAttached : public QObject
      */
     Q_PROPERTY(ColumnView *view READ view NOTIFY viewChanged)
 
+    /**
+     * True if this column is at least partly visible in the ColumnView's viewport.
+     * @since 5.77
+     */
+    Q_PROPERTY(bool inViewport READ inViewport NOTIFY inViewportChanged)
+
 public:
     ColumnViewAttached(QObject *parent = nullptr);
     ~ColumnViewAttached();
@@ -84,6 +103,9 @@ public:
     bool isPinned() const;
     void setPinned(bool pinned);
 
+    bool inViewport() const;
+    void setInViewport(bool inViewport);
+
 Q_SIGNALS:
     void indexChanged();
     void fillWidthChanged();
@@ -91,6 +113,8 @@ Q_SIGNALS:
     void viewChanged();
     void preventStealingChanged();
     void pinnedChanged();
+    void scrollIntention(ScrollIntentionEvent *event);
+    void inViewportChanged();
 
 private:
     int m_index = -1;
@@ -103,9 +127,9 @@ private:
     bool m_shouldDeleteOnRemove = true;
     bool m_preventStealing = false;
     bool m_pinned = false;
+    bool m_inViewport = false;
 };
 
-
 /**
  * ColumnView is a container that lays out items horizontally in a row,
  * when not all items fit in the ColumnView, it will behave like a Flickable and will be a scrollable view which shows only a determined number of columns.
@@ -214,6 +238,11 @@ class ColumnView : public QQuickItem
      */
     Q_PROPERTY(bool interactive READ interactive WRITE setInteractive NOTIFY interactiveChanged)
 
+    /**
+     * True if the contents can be dragged also with mouse besides touch
+     */
+    Q_PROPERTY(bool acceptsMouse READ acceptsMouse WRITE setAcceptsMouse NOTIFY acceptsMouseChanged)
+
     // Default properties
     /**
      * Every column item the view contains
@@ -225,14 +254,14 @@ class ColumnView : public QQuickItem
     Q_PROPERTY(QQmlListProperty<QObject> contentData READ contentData  FINAL)
     Q_CLASSINFO("DefaultProperty", "contentData")
 
-    Q_ENUMS(ColumnResizeMode)
-
 public:
     enum ColumnResizeMode {
         FixedColumns = 0,
         DynamicColumns,
         SingleColumn
     };
+    Q_ENUM(ColumnResizeMode)
+
     ColumnView(QQuickItem *parent = nullptr);
     ~ColumnView();
 
@@ -283,6 +312,9 @@ public:
     bool interactive() const;
     void setInteractive(bool interactive);
 
+    bool acceptsMouse() const;
+    void setAcceptsMouse(bool accepts);
+
     // Api not intended for QML use
     //can't do overloads in QML
     QQuickItem *removeItem(QQuickItem *item);
@@ -391,6 +423,7 @@ Q_SIGNALS:
     void contentXChanged();
     void contentWidthChanged();
     void interactiveChanged();
+    void acceptsMouseChanged();
     void scrollDurationChanged();
     void separatorVisibleChanged();
     void firstVisibleItemChanged();
@@ -418,6 +451,8 @@ private:
     static QHash<QObject *, ColumnViewAttached *> m_attachedObjects;
     qreal m_oldMouseX = -1.0;
     qreal m_startMouseX = -1.0;
+    qreal m_oldMouseY = -1.0;
+    qreal m_startMouseY = -1.0;
     int m_currentIndex = -1;
     qreal m_topPadding = 0;
     qreal m_bottomPadding = 0;
@@ -428,6 +463,7 @@ private:
     bool m_moving = false;
     bool m_separatorVisible = true;
     bool m_complete = false;
+    bool m_acceptsMouse = false;
 };
 
 QML_DECLARE_TYPEINFO(ColumnView, QML_HAS_ATTACHED_PROPERTIES)
