@@ -17,14 +17,21 @@
  */
 
 #include "imagecolors.h"
+#include "platformtheme.h"
 
-#include <QColor>
 #include <QDebug>
 #include <QTimer>
 #include <QtConcurrent>
 
 #include <cmath>
 
+#define return_fallback(value) if (m_imageData.m_samples.size() == 0) {\
+    return value;\
+}
+
+#define return_fallback_finally(value, finally) if (m_imageData.m_samples.size() == 0) {\
+    return value.isValid() ? value : static_cast<Kirigami::PlatformTheme*>(qmlAttachedPropertiesObject<Kirigami::PlatformTheme>(this, true))->finally();\
+}
 
 ImageColors::ImageColors(QObject *parent)
     : QObject(parent)
@@ -246,7 +253,7 @@ ImageData ImageColors::generatePalette(const QImage &sourceImage)
             b = 0;
             c = 0;
 
-            for (auto color : stat.colors) {
+            for (auto color : qAsConst(stat.colors)) {
                 c++;
                 r += qRed(color);
                 g += qGreen(color);
@@ -260,7 +267,7 @@ ImageData ImageColors::generatePalette(const QImage &sourceImage)
             stat.colors = QList<QRgb>({stat.centroid});
         }
 
-        for (auto color : imageData.m_samples) {
+        for (auto color : qAsConst(imageData.m_samples)) {
             positionColor(color, imageData.m_clusters);
         }
     }
@@ -290,7 +297,7 @@ ImageData ImageColors::generatePalette(const QImage &sourceImage)
             }
         }
     }
-    for (const auto &i : itemsToDelete) {
+    for (const auto &i : qAsConst(itemsToDelete)) {
         imageData.m_clusters.erase(i);
     }
 
@@ -303,7 +310,7 @@ ImageData ImageColors::generatePalette(const QImage &sourceImage)
 
     bool first = true;
 
-    for (const auto &stat : imageData.m_clusters) {
+    for (const auto &stat : qAsConst(imageData.m_clusters)) {
         QVariantMap entry;
         const QColor color(stat.centroid);
         entry[QStringLiteral("color")] = color;
@@ -315,7 +322,7 @@ ImageData ImageColors::generatePalette(const QImage &sourceImage)
                         128 + (128 - contrast.lightness()));
         QColor tempContrast;
         int minimumDistance = 4681800; //max distance: 4*3*2*3*255*255
-        for (const auto &stat : imageData.m_clusters) {
+        for (const auto &stat : qAsConst(imageData.m_clusters)) {
             const int distance = squareDistance(contrast.rgb(), stat.centroid);
 
             if (distance < minimumDistance) {
@@ -370,11 +377,14 @@ ImageData ImageColors::generatePalette(const QImage &sourceImage)
 
 QVariantList ImageColors::palette() const
 {
+    if (m_futureImageData) qWarning()<< m_futureImageData->future().isFinished();
+    return_fallback(m_fallbackPalette)
     return m_imageData.m_palette;
 }
 
 ColorUtils::Brightness ImageColors::paletteBrightness() const
 {
+    return_fallback(m_fallbackPaletteBrightness)
     return qGray(m_imageData.m_dominant.rgb()) < 128
             ? ColorUtils::Dark
             : ColorUtils::Light;
@@ -382,21 +392,25 @@ ColorUtils::Brightness ImageColors::paletteBrightness() const
 
 QColor ImageColors::average() const
 {
+    return_fallback_finally(m_fallbackAverage, linkBackgroundColor)
     return m_imageData.m_average;
 }
 
 QColor ImageColors::dominant() const
 {
+    return_fallback_finally(m_fallbackDominant, linkBackgroundColor)
     return m_imageData.m_dominant;
 }
 
 QColor ImageColors::dominantContrast() const
 {
+    return_fallback_finally(m_fallbackDominantContrasting, linkBackgroundColor)
     return m_imageData.m_dominantContrast;
 }
 
 QColor ImageColors::foreground() const
 {
+    return_fallback_finally(m_fallbackForeground, textColor)
     if (paletteBrightness() == ColorUtils::Dark) {
         if (qGray(m_imageData.m_closestToWhite.rgb()) < 200) {
             return QColor(230, 230, 230);
@@ -412,6 +426,7 @@ QColor ImageColors::foreground() const
 
 QColor ImageColors::background() const
 {
+    return_fallback_finally(m_fallbackBackground, backgroundColor)
     if (paletteBrightness() == ColorUtils::Dark) {
         if (qGray(m_imageData.m_closestToBlack.rgb()) > 80) {
             return QColor(20, 20, 20);
@@ -427,11 +442,13 @@ QColor ImageColors::background() const
 
 QColor ImageColors::highlight() const
 {
+    return_fallback_finally(m_fallbackHighlight, linkColor)
     return m_imageData.m_highlight;
 }
 
 QColor ImageColors::closestToWhite() const
 {
+    return_fallback(Qt::white)
     if (qGray(m_imageData.m_closestToWhite.rgb()) < 200) {
         return QColor(230, 230, 230);
     }
@@ -440,6 +457,7 @@ QColor ImageColors::closestToWhite() const
 
 QColor ImageColors::closestToBlack() const
 {
+    return_fallback(Qt::black)
     if (qGray(m_imageData.m_closestToBlack.rgb()) > 80) {
         return QColor(20, 20, 20);
     }
