@@ -89,7 +89,7 @@ ToolBarLayout::ToolBarLayout(QQuickItem *parent)
     d->removalTimer->setInterval(1000);
     d->removalTimer->setSingleShot(true);
     connect(d->removalTimer, &QTimer::timeout, this, [this]() {
-        for (auto action : d->removedActions) {
+        for (auto action : qAsConst(d->removedActions)) {
             if (!d->actions.contains(action)) {
                 d->delegates.erase(action);
             }
@@ -112,6 +112,18 @@ void ToolBarLayout::addAction(QObject* action)
     d->actions.append(action);
     d->actionsChanged = true;
 
+    connect(action, &QObject::destroyed, this, [this](QObject *action) {
+        auto itr = d->delegates.find(action);
+        if (itr != d->delegates.end()) {
+            d->delegates.erase(itr);
+        }
+
+        d->actions.removeOne(action);
+        d->actionsChanged = true;
+
+        relayout();
+    });
+
     relayout();
 }
 
@@ -132,7 +144,7 @@ void ToolBarLayout::removeAction(QObject* action)
 
 void ToolBarLayout::clearActions()
 {
-    for (auto action : d->actions) {
+    for (auto action : qAsConst(d->actions)) {
         auto itr = d->delegates.find(action);
         if (itr != d->delegates.end()) {
             itr->second->hide();
@@ -346,7 +358,7 @@ void ToolBarLayout::Private::performLayout()
     // First, calculate the total width and maximum height of all delegates.
     // This will be used to determine which actions to show, which ones to
     // collapse to icon-only etc.
-    for (auto entry : sortedDelegates) {
+    for (auto entry : qAsConst(sortedDelegates)) {
         if (!entry->isActionVisible()) {
             entry->hide();
             continue;
@@ -423,7 +435,7 @@ void ToolBarLayout::Private::performLayout()
     }
 
     qreal currentX = layoutStart(visibleActionsWidth);
-    for (auto entry : sortedDelegates) {
+    for (auto entry : qAsConst(sortedDelegates)) {
         if (!entry->isVisible()) {
             continue;
         }
@@ -484,7 +496,7 @@ QVector<ToolBarLayoutDelegate*> ToolBarLayout::Private::createDelegates()
     }
 
     if (!moreButtonInstance && !moreButtonIncubator) {
-        moreButtonIncubator = new ToolBarDelegateIncubator(moreButton, qmlContext(q));
+        moreButtonIncubator = new ToolBarDelegateIncubator(moreButton, qmlContext(moreButton));
         moreButtonIncubator->setStateCallback([this](QQuickItem *item) {
             item->setParentItem(q);
         });
@@ -523,7 +535,7 @@ ToolBarLayoutDelegate *ToolBarLayout::Private::createDelegate(QObject* action)
 
     auto result = new ToolBarLayoutDelegate(q);
     result->setAction(action);
-    result->createItems(fullComponent, iconDelegate, qmlContext(q), [this, action](QQuickItem *newItem) {
+    result->createItems(fullComponent, iconDelegate, [this, action](QQuickItem *newItem) {
         newItem->setParentItem(q);
         auto attached = static_cast<ToolBarLayoutAttached*>(qmlAttachedPropertiesObject<ToolBarLayout>(newItem, true));
         attached->setAction(action);
